@@ -23,7 +23,7 @@ class CloudStackOffering(BaseModel):
                                          help_text="Cloud Stack Offering name")
     weaker = models.BooleanField(verbose_name=_("Is the weaker offering"), default=False)
     region = models.ForeignKey('CloudStackRegion', related_name="cs_offering_region", null=True)
-    equivalent_offering = models.ForeignKey('CloudStackOffering', null=True, blank= True)
+    equivalent_offering = models.ForeignKey('CloudStackOffering', null=True, blank= True, on_delete=models.SET_NULL)
 
 
 class CloudStackBundle(BaseModel):
@@ -41,7 +41,6 @@ class CloudStackBundle(BaseModel):
                                              help_text="Cloud Stack Zone Name")
     region = models.ForeignKey('CloudStackRegion', related_name="cs_bundle_region", null=True)
 
-
 class CloudStackRegion(BaseModel):
     name = models.CharField(verbose_name=_("Name"),
                  max_length=100,
